q1ss.binalg.affine
==================

.. automodule:: q1ss.binalg.affine

AffineSubspace
--------------

.. autoclass:: q1ss.binalg.affine.AffineSubspace
    :show-inheritance:
    :members:
    :special-members: __eq__, __add__, __sub__, __radd__, __rmatmul__, __contains__

BinvecLabelFun
--------------

.. autoclass:: q1ss.binalg.affine.BinvecLabelFun
    :show-inheritance:
    :members:

HypercubeAxes
-------------

.. autodata:: q1ss.binalg.affine.HypercubeAxes

draw_hypercube
--------------

.. autofunction:: q1ss.binalg.affine.draw_hypercube
